/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.commons.compress.compressors.deflate;

import java.io.ByteArrayOutputStream;
import java.io.IOException;

import org.junit.Assert;
import org.junit.jupiter.api.Test;

public class DeflateCompressorOutputStreamTest {

    @Test
    public void canReadASingleByteFlushAndFinish() throws IOException {
        try (final ByteArrayOutputStream bos = new ByteArrayOutputStream();
                final DeflateCompressorOutputStream cos = new DeflateCompressorOutputStream(bos)) {
            cos.write(99);
            cos.flush();
            cos.finish();
            Assert.assertTrue(bos.toByteArray().length > 0);
        }
    }

}
